@@ -23,8 +23,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef SCREENLOCKER_KSLDAPP_H
 #define SCREENLOCKER_KSLDAPP_H
 
-#include <QtCore/QElapsedTimer>
-#include <QtCore/QProcessEnvironment>
+#include <QElapsedTimer>
+#include <QProcessEnvironment>
 
 #include <KScreenLocker/kscreenlocker_export.h>
 
@@ -70,8 +70,8 @@ public:
 
     static KSldApp* self();
 
-    KSldApp(QObject * parent = 0);
-    virtual ~KSldApp();
+    explicit KSldApp(QObject * parent = nullptr);
+    ~KSldApp() override;
 
     LockState lockState() const {
         return m_lockState;
@@ -127,14 +127,6 @@ public:
         m_lockGrace = msec;
     }
 
-    bool forceSoftwareRendering() const {
-        return m_forceSoftwareRendering;
-    }
-
-    void setForceSoftwareRendering(bool force) {
-        m_forceSoftwareRendering = force;
-    }
-
 Q_SIGNALS:
     void locked();
     void unlocked();
@@ -187,7 +179,6 @@ private:
     LogindIntegration *m_logind;
     GlobalAccel *m_globalAccel = nullptr;
     bool m_hasXInput2 = false;
-    bool m_forceSoftwareRendering = false;
 
     bool m_isX11;
     bool m_isWayland;
